# UniPose - 2D Pose in Unity, using Pytorch PoseNet
Written by Julie Ganeshan

*This codebase is adapted from https://github.com/rwightman/posenet-pytorch* Please see `original_docs`

All rights for PoseNet in Pytorch to Ross Wightman. My modifications 
are entirely contained in `pose_server.py`

*The model weights are from Google*


For the full docs, see the github repo 

https://github.com/Sanjay-Ganeshan/UniPose


*This package relies on Pytorch, and is only compatible with Windows 10*

Please install Pytorch, as per https://pytorch.org/get-started/locally/ - this is NOT auto installed.

To install this package, just use

`pip install unipose`
